← Back to team overview

openlp-core team mailing list archive

[Merge] lp:~trb143/openlp/fixes245 into lp:openlp/2.4

 

Tim Bentley has proposed merging lp:~trb143/openlp/fixes245 into lp:openlp/2.4.

Requested reviews:
  OpenLP Core (openlp-core)
Related bugs:
  Bug #1660473 in OpenLP: "OSZL is ignored on save (inconsistent gui)"
  https://bugs.launchpad.net/openlp/+bug/1660473

For more details, see:
https://code.launchpad.net/~trb143/openlp/fixes245/+merge/316049

Fix incorrect menu link 

lp:~trb143/openlp/fixes245 (revision 2670)
[SUCCESS] https://ci.openlp.io/job/Branch-01-Pull/1898/
[SUCCESS] https://ci.openlp.io/job/Branch-02-Functional-Tests/1809/
[SUCCESS] https://ci.openlp.io/job/Branch-03-Interface-Tests/1748/
[SUCCESS] https://ci.openlp.io/job/Branch-04a-Windows_Functional_Tests/1484/
[SUCCESS] https://ci.openlp.io/job/Branch-04b-Windows_Interface_Tests/1074/
[SUCCESS] https://ci.openlp.io/job/Branch-05a-Code_Analysis/1142/
[SUCCESS] https://ci.openlp.io/job/Branch-05b-Test_Coverage/1010/
-- 
Your team OpenLP Core is requested to review the proposed merge of lp:~trb143/openlp/fixes245 into lp:openlp/2.4.
=== modified file 'openlp/core/ui/mainwindow.py'
--- openlp/core/ui/mainwindow.py	2017-01-21 20:50:30 +0000
+++ openlp/core/ui/mainwindow.py	2017-01-31 19:13:52 +0000
@@ -189,7 +189,7 @@
                                             triggers=self.service_manager_contents.on_load_service_clicked)
         self.file_save_item = create_action(main_window, 'fileSaveItem', icon=':/general/general_save.png',
                                             can_shortcuts=True, category=UiStrings().File,
-                                            triggers=self.service_manager_contents.save_file)
+                                            triggers=self.service_manager_contents.decide_save_method)
         self.file_save_as_item = create_action(main_window, 'fileSaveAsItem', can_shortcuts=True,
                                                category=UiStrings().File,
                                                triggers=self.service_manager_contents.save_file_as)

=== modified file 'tests/functional/openlp_core_ui/test_aboutform.py'
--- tests/functional/openlp_core_ui/test_aboutform.py	2016-12-31 11:05:48 +0000
+++ tests/functional/openlp_core_ui/test_aboutform.py	2017-01-31 19:13:52 +0000
@@ -22,36 +22,53 @@
 """
 Package to test the openlp.core.ui.firsttimeform package.
 """
-from unittest.mock import patch
+from unittest import TestCase
 
 from openlp.core.ui.aboutform import AboutForm
 
-
-@patch('openlp.core.ui.aboutform.get_application_version')
-def test_create_about_form(mocked_get_application_version):
-    """
-    Test creating an about form
-    """
-    # GIVEN: An application version with a build number
-    mocked_get_application_version.return_value = {'version': '3.1.1', 'build': '3000'}
-
-    # WHEN: The about form is created
-    about_form = AboutForm(None)
-
-    # THEN: The correct version information should be in the dialog
-    assert 'OpenLP 3.1.1 build 3000' in about_form.about_text_edit.toPlainText()
-
-
-@patch('openlp.core.ui.aboutform.webbrowser')
-def test_on_volunteer_button_clicked(mocked_webbrowser):
-    """
-    Test that clicking on the "Volunteer" button opens a web page.
-    """
-    # GIVEN: A new About dialog and a mocked out webbrowser module
-    about_form = AboutForm(None)
-
-    # WHEN: The "Volunteer" button is "clicked"
-    about_form.on_volunteer_button_clicked()
-
-    # THEN: A web browser is opened
-    mocked_webbrowser.open_new.assert_called_with('http://openlp.org/en/contribute')
+from tests.functional import patch
+from tests.helpers.testmixin import TestMixin
+
+
+class TestAboutForm(TestCase, TestMixin):
+
+    @patch('openlp.core.ui.aboutform.get_application_version')
+    def test_create_about_form(self, mocked_get_application_version):
+        """
+        Test creating an about form
+        """
+        # GIVEN: An application version with a build number
+        mocked_get_application_version.return_value = {'version': '3.1.1', 'build': '3000'}
+
+        # WHEN: The about form is created
+        about_form = AboutForm(None)
+
+        # THEN: The correct version information should be in the dialog
+        assert 'OpenLP 3.1.1 build 3000' in about_form.about_text_edit.toPlainText()
+
+    @patch('openlp.core.ui.aboutform.webbrowser')
+    def test_on_volunteer_button_clicked(self, mocked_webbrowser):
+        """
+        Test that clicking on the "Volunteer" button opens a web page.
+        """
+        # GIVEN: A new About dialog and a mocked out webbrowser module
+        about_form = AboutForm(None)
+
+        # WHEN: The "Volunteer" button is "clicked"
+        about_form.on_volunteer_button_clicked()
+
+        # THEN: A web browser is opened
+        mocked_webbrowser.open_new.assert_called_with('http://openlp.org/en/contribute')
+
+    def test_about_form_date_test(self):
+        """
+        Test that the copyright date is included correctly
+        """
+        # GIVEN: A correct application date
+        # WHEN: The about form is created
+        about_form = AboutForm(None)
+        license_text = about_form.license_text_edit.toPlainText()
+
+        # THEN: The date should be in the text twice.
+        self.assertTrue(license_text.count('2017', 0) == 2,
+                        "The text string should be added twice to the license string")


Follow ups